################################################################
#
#   Assembly Line - Bonuses
#
################################################################

from random import choice
from format import format_dollars

bonus_kinds = ('monthly', 'lifetime')
kind_titles = {'monthly': "Monthly", 'lifetime': "Lifetime"}
lifetime_target_scale = 3

class Bonus(object):
	#  kind      'monthly' or 'lifetime'
	#  target    int
	#  reward    int
	
	format_target = staticmethod(format_dollars)

	def __init__(self, kind, company):
		self.kind = kind
		if kind == 'monthly':
			s = 1
			basis = self.max_monthly_achievement(company)
		else:
			s = lifetime_target_scale
			basis = (self.lifetime_achievement(company)
				+ s * self.max_monthly_achievement(company) - 1)
		b = max(basis, self.min_target - 1) / self.base_target
		m = s * next_multiplier_greater_than(b)
		self.target = m * self.base_target
		self.reward = m * self.base_reward
	
	def max_monthly_achievement(self, company):
		achievement = self.achievement
		seq = [achievement(stats) for stats in company.stats]
		if seq:
			return max(seq)
		else:
			return 0
	
	def lifetime_achievement(self, company):
		return self.achievement(company.total)
		
	def company_achievement(self, company):
		if self.kind == 'lifetime':
			stats = company.total
		else:
			stats = company.stats_for_current_period()
		return self.achievement(stats)
	
	def achieved(self, company):
		achievement = self.company_achievement(company)
		return achievement >= self.target
	
	def title_text(self):
		return "%s %s" % (kind_titles[self.kind], self.title)
	
	def target_text(self):
		return self.format_target(self.target)
	
	def reward_text(self):
		return format_dollars(self.reward)

#------------------------------------------------------------------------

mantissas = [1, 2, 5]

def multiplier(magnitude):
	m = mantissas
	e, i = divmod(magnitude, len(m))
	return m[i] * 10 ** e

def next_multiplier_greater_than(x):
	i = 0
	while 1:
		y = multiplier(i)
		if y > x:
			return y
		i += 1

#------------------------------------------------------------------------

class ProfitBonus(Bonus):

	title = "Profit"
	base_target = 1000
	min_target = 1000
	base_reward = 100

	def achievement(self, stats):
		return stats.calc_profit()

#------------------------------------------------------------------------

class SalesVolumeBonus(Bonus):

	title = "Units Sold"
	base_target = 100
	min_target = 200
	base_reward = 50
	format_target = int
	
	def achievement(self, stats):
		return stats.calc_profit()

#------------------------------------------------------------------------

class SalesValueBonus(Bonus):

	title = "Sales Value"
	base_target = 10000
	min_target = 30000
	base_reward = 30

	def achievement(self, stats):
		return stats.calc_profit()

#------------------------------------------------------------------------

bonus_types = [ProfitBonus, SalesVolumeBonus, SalesValueBonus]

def create_random_bonus(company):
	cls = choice(bonus_types)
	kind = choice(bonus_kinds)
	return cls(kind, company)
