################################################################
#
#   Assembly Line - User interface for salary and bonuses
#
################################################################

from albow.controls import Label, Row, Column, ValueView, Grid, Button
from albow.resource import get_font
from decoration import Lineflow
from game import game
from format import format_dollars

heading_font = get_font(15, "VeraBd.ttf")
data_font = get_font(12, "Vera.ttf")
accept_font = get_font(10, "Vera.ttf")

#------------------------------------------------------------------------

class BonusView(Column):

	def __init__(self):
		def L(text):
			return Label(text, font = data_font)
		def V(get, align = 'l', **kwds):
			return ValueView(get_value = get, align = align, font = data_font,
				**kwds)
		header = Label("Current Target", font = heading_font)
		title = V(self.get_title, width = 145)
		target = V(self.get_target, 'r')
		reward = V(self.get_reward, 'r')
		rows = [
			[title, target],
			[L("Bonus"), reward],
		]
		grid = Grid(rows, row_spacing = 0)
		Column.__init__(self, [header, grid], align = 'l')
	
	def get_title(self):
		bonus = game.company.current_bonus
		if bonus:
			return bonus.title_text()

	def get_target(self):
		bonus = game.company.current_bonus
		if bonus:
			return bonus.target_text()
	
	def get_reward(self):
		bonus = game.company.current_bonus
		if bonus:
			return bonus.reward_text()

#------------------------------------------------------------------------

class SalaryView(Column):

	def __init__(self):
		def L(text):
			return Label(text, font = data_font)
		def V(get):
			return ValueView(get_value = get, align = 'r', font = data_font)
		header = Label("Personal Finances", font = heading_font)
		salary = V(self.get_salary)
		wealth = V(self.get_wealth)
		salary_owed = V(self.get_salary_owed)
		bonuses_owed = V(self.get_bonuses_owed)
		rows = [
			[L("Current Salary"), salary],
			[L("Wealth"), wealth],
			[L("Salary Owed"), salary_owed],
			[L("Bonuses Owed"), bonuses_owed],
		]
		grid = Grid(rows, row_spacing = 0)
		offer = SalaryOfferView()
		Column.__init__(self, [header, grid, offer], align = 'l')
	
	def get_salary(self):
		return format_dollars(12 * game.company.player.salary)
	
	def get_wealth(self):
		return format_dollars(game.company.player.cash)

	def get_salary_owed(self):
		return format_dollars(game.company.get_salary_owed())

	def get_bonuses_owed(self):
		return format_dollars(game.company.get_bonuses_owed())

#------------------------------------------------------------------------

class SalaryOfferView(Row):

	def __init__(self):
		label = Label("Salary Offer", font = data_font)
		button = Button("Accept", font = accept_font, action = self.accept)
		offer = ValueView(get_value = self.get_offer, font = data_font, align = 'r')
		contents = [label, offer, button]
		Row.__init__(self, contents)
	
	def get_visible(self):
		return game.company.player.salary_raise_offer > 0
	
	def get_offer(self):
		return 12 * game.company.player.salary_raise_offer

	def accept(self):
		game.company.accept_salary_raise_offer()
