################################################################
#
#   Assembly Line - Decorative user interface elements
#
################################################################

from albow.widget import Widget
from albow.tab_panel import TabPanel
from albow.resource import get_image
from albow.image_array import get_image_array

#-----------------------------------------------------------------------

class Lineflow(Widget):

	sprocket_hole_width = 16
	sprocket_hole_image = get_image("lineflow_hole.png")
	paper_color = (255, 255, 255)
	stripe_color = (255, 227, 183)
	margin = 10
	
	def __init__(self, client, **kwds):
		Widget.__init__(self, **kwds)
		self.client = client
		client.anchor = 'ltrb'
		w, h = client.size
		s = self.sprocket_hole_width
		m = self.margin
		self.size = (w + 2 * (s + m), h + 2 * m)
		client.topleft = (s + m, m)
		self.add(client)
	
	def draw(self, surf):
		width, height = surf.get_size()
		hole = self.sprocket_hole_image
		hw, hh = hole.get_size()
		y = 0
		while y < height:
			surf.blit(hole, (0, y))
			surf.blit(hole, (width - hw, y))
			y += hh
		bg = self.paper_color
		sc = self.stripe_color
		stripe_width = width - 2 * hw
		y = 2 * hh
		surf.fill(bg, (hw, 0, stripe_width, y))
		while y < height:
			surf.fill(sc, (hw, y, stripe_width, hh))
			y += hh
			surf.fill(bg, (hw, y, stripe_width, hh))
			y += hh

#-----------------------------------------------------------------------

class PostitTabPanel(TabPanel):
	#  A tab panel with tabs resembling Post-It notes.

	tab_margin = 20
	tab_spacing = 10
	tab_overlap = 10
	tab_border_width = 0
	default_tab_bg_color = (255, 255, 81)
	use_page_bg_color_for_tabs = False
	
	def draw_tabs(self, surf):
		pass
	
	def draw_over(self, surf):
		TabPanel.draw_tabs(self, surf)
	
	def draw_tab_bg(self, surf, page, selected, rect):
		if selected:
			rect.height += self.tab_overlap
		TabPanel.draw_tab_bg(self, surf, page, selected, rect)

#-----------------------------------------------------------------------

class PaperTabPanel(TabPanel):
	#  Tab panel with rounded, slant-sided tabs.

	tab_images = get_image_array("paper_tabs.png", (2, 2))
	tab_height = tab_images[0, 0].get_height()
	tab_border_width = 0

	def draw_tab_bg(self, surf, page, selected, rect):
		images = self.tab_images
		left = images[selected, 0]
		right = images[selected, 1]
		wl, hl = left.get_size()
		wr, hr = right.get_size()
		surf.blit(left, rect.topleft)
		surf.blit(right, (rect.right - wr, rect.top))
		c = right.get_at((0, hr - 1))
		surf.fill(c, (wl, 0, rect.width - wl - wr, rect.height))
