################################################################
#
#   Assembly Line - Factory Menu
#
################################################################

from albow.controls import Label, Button, TextEditor, Row, Column
from albow.dialogs import Dialog
from albow.palette_view import PaletteView
from albow.resource import get_font
from game import game

#------------------------------------------------------------------------

button_font = get_font(12, "VeraBd.ttf")

class FactoryMenu(Dialog):

	click_outside_response = True

	def __init__(self):
		title_field = TextEditor(width = 250, model = self, attribute = 'factory_title')
		factory_list = FactorySelector(action = self.ok)
		new_button = FMButton("Open New Factory", action = self.new_factory)
		del_button = FMButton("Close Factory", action = self.close_factory)
		rows = [
			Label("Current Factory"),
			factory_list,
			Row([Label("Name"), title_field]),
			Row([new_button, del_button]),
		]
		contents = Column(rows, align = 'l')
		Dialog.__init__(self, contents)
	
	def get_factory_title(self):
		return game.factory().title
	
	def set_factory_title(self, x):
		game.factory().title = x
	
	factory_title = property(get_factory_title, set_factory_title)
	
#	def can_close_factory(self):
#		return len(game.company.factories) > 1
	
	def new_factory(self):
		game.company.new_factory()
	
	def close_factory(self):
		game.company.close_factory()

def FMButton(text, **kwds):
	return Button(text, font = button_font, **kwds)

#------------------------------------------------------------------------

class FactorySelector(PaletteView):

	cell_width = 300
	default_num_rows = 10
	border_width = 1

	def __init__(self, **kwds):
		cw = self.cell_width
		ch = self.font.get_linesize()
		nr = self.default_num_rows
		PaletteView.__init__(self, cell_size = (cw, ch),
			nrows = nr, ncols = 1, scrolling = True, **kwds)
	
	def factory_no(self, n):
		return game.company.factories[n]
	
	def num_items(self):
		return len(game.company.factories)
	
	def item_is_selected(self, n):
		return self.factory_no(n) is game.factory()
	
	def click_item(self, n, e):
		game.company.select_factory(self.factory_no(n))
		if e.num_clicks == 2:
			self.action()

	def draw_item(self, surf, n, rect):
		factory = self.factory_no(n)
		buf = self.font.render(factory.title, True, self.fg_color)
		surf.blit(buf, rect)

	def action(self):
		pass
