################################################################
#
#   Assembly Line - Conveyor drive
#
################################################################

from pygame import Rect
from albow.controls import Label, Column, Grid
from albow.dialogs import Dialog
from albow.resource import get_image, get_font
from albow.image_array import get_image_array
from controls import TextMultichoice, MachineEditor
from machine import Machine

#------------------------------------------------------------------------

class ConveyorDriveEditor(MachineEditor):

	def create_contents(self, machine):
		rows = [
			[Label("Direction"), DirectionField(machine)],
		]
		return Grid(rows)

def DirectionField(machine):
	return TextMultichoice(values = [1, -1], labels = ["Forward", "Reverse"],
		margin = 2, border_width = 1, attribute = 'direction', model = machine)

#------------------------------------------------------------------------

class ConveyorDrive(Machine):

	title = "Conveyor Drive"
	icon = get_image("conveyor_drive_icon.png")
	rotation_mask = 3
	layer = 0
	is_conveyor_drive = True
	cost = 200
	num_phases = 8
	editor_class = ConveyorDriveEditor

	orgx, orgy = -16, -16
	
	local_bounding_rect = Rect(orgx, orgy, 32, 32)

	local_covered_rects = [
		[local_bounding_rect],
		[]
	]
	
	local_feedback_rects = [
		Rect(orgx + 8, orgy, 16, 24),
	]

	images = get_image_array("conveyor_drive.png", 4, border = 2)
	
	phase = 0
	direction = 1
	running = True

	def draw_local(self, surf, t):
		org = self.local_topleft()
		t.draw_image(surf, self.images, org)

	def adjacent_direction(self):
		return self.global_vector((0, -1))

	def begin_frame(self, factory):
		if self.running:
			self.phase = (self.phase + self.direction) % self.num_phases
