################################################################
#
#   Assembly Line - Hopper base class
#
################################################################

from pygame import Rect
from albow.controls import Label, Row, IntEditor
from albow.resource import get_sound
from settings import game_minutes_to_frames
from machine import Machine

#------------------------------------------------------------------------

delivery_rate_denominator = 24 * 60 # game minutes

#------------------------------------------------------------------------

def SupplyRateField(machine, desc):
	f = IntEditor(min = 0, max = 60, empty = None, attribute = "supply_rate", model = machine)
	return Row([f, Label("%s per day" % desc)])

#------------------------------------------------------------------------

class Hopper(Machine):
	#  supply_rate     int

	release_sound = get_sound("hopper_release.ogg")
	is_resettable = True
	layer = 1

	local_delivery_point = (0, 0)
	
	supply_rate = 12

	def check_ready(self):
		if self.supply_rate is None:
			raise MachineNotConfiguredError

	def change_state(self, factory):
		rate = self.supply_rate
		if rate:
			part = self.get_part(factory)
			if part:
				self.deliver_part(factory, part)
			game_minutes = delivery_rate_denominator // rate
			self.timeout = game_minutes_to_frames(game_minutes)

	def deliver_part(self, factory, part):
		p = self.global_point(self.local_delivery_point)
		#print "%s: Delivering" % self.__class__.__name__, part, \
		#	"to factory", factory.title, "at", p ###
		factory.add_part(part, p)
		factory.queue_sound(self.release_sound)

	def draw_local(self, surf, t):
		org = self.local_topleft()
		t.draw_image(surf, [self.image], org)
