################################################################
#
#   Assembly Line - Recycle Bin
#
################################################################

from pygame import Rect
from albow.resource import get_image, get_sound
from machine import Machine
from game import game

#------------------------------------------------------------------------

class RecycleBin(Machine):
	#  num_parts     int
	#  total_value   float
	
	title = "Recycle Bin"
	cost = 100
	layer = 0
	rotation_mask = 1
	icon = get_image("recycle_bin_icon.png")
	#image = get_image("recycle_bin.png", border = 2)
	images = [
		get_image("recycle_bin_r0.png", border = 2),
		get_image("recycle_bin_r1.png", border = 2),
	]
	bin_sound = get_sound("recycle.ogg")
	
	capacity = 10 # 100

	num_parts = 0
	total_value = 0.0

	local_bounding_rect = Rect(-16, -32, 32, 64)

	local_covered_rects = [
		[local_bounding_rect],
		[]
	]
	
	def draw_local(self, surf, t):
		org = self.local_topleft()
		t.draw_image(surf, self.images, org, local_rect = self.local_bounding_rect)

	def handle_part(self, factory, part):
		#print "RecycleBin: eating", part ###
		self.num_parts += 1
		self.total_value += part.raw_material_cost()
		factory.remove_part(part)
		factory.queue_sound(self.bin_sound)
		if self.num_parts >= self.capacity:
			#print "RecycleBin: selling scrap with cost", self.total_value ###
			value = self.total_value
			amount = game.company.sell_parts_for_scrap(self.num_parts, value)
			factory.add_stats(material_sale = amount)
			self.num_parts = 0
			self.total_value = 0
