################################################################
#
#   Assembly Line - Storage Hopper
#
################################################################

from pygame import Rect
from albow.controls import Label, Grid
from albow.resource import get_image, get_sound
from controls import MachineEditor
from hopper import Hopper, SupplyRateField

#------------------------------------------------------------------------

class StorageHopperEditor(MachineEditor):

	def create_contents(self, machine):
		rows = [
			[Label("Supply Rate"), SupplyRateField(machine, "parts")],
		]
		return Grid(rows)

#------------------------------------------------------------------------

class StorageHopper(Hopper):
	#  contents   [Part]

	title = "Storage Hopper"
	icon = get_image("storage_hopper_icon.png")
	image = get_image("storage_hopper.png")
	cost = 500
	editor_class = StorageHopperEditor
	accept_sound = get_sound("hopper_accept.ogg")
	reject_sound = get_sound("hopper_reject.ogg")

	local_bounding_rect = Rect(-32, -96, 64, 128)

	local_covered_rects = [
		[Rect(-32, -96, 64, 64)],
		[local_bounding_rect]
	]
	
	local_input_rect = Rect(-32, -96, 64, 64)
	local_rejection_point = (0, 32)
	level_gauge_rect = Rect(13, -28, 8, 24)
	rejection_spread = 8
	
	capacity = 10

	def __init__(self):
		Hopper.__init__(self)
		self.contents = []
	
	def reset(self, factory):
		Hopper.reset(self, factory)
		contents = self.contents
		p = self.global_point(self.local_input_rect.center)
		for part in self.contents:
			factory.add_part(part, p)
		del contents[:]
	
	def handle_part(self, factory, part):
		if self.part_in_rect(part, self.local_input_rect):
			contents = self.contents
			if len(contents) < self.capacity:
				factory.remove_part(part)
				contents.append(part)
				factory.queue_sound(self.accept_sound)
			else:
				self.reject_part(factory, part)
				return True
	
	def reject_part(self, factory, part):
		self.scatter_part(factory, part, self.local_rejection_point,
			self.rejection_spread)
		factory.queue_sound(self.reject_sound)

	def get_part(self, factory):
		contents = self.contents
		if contents:
			part = contents.pop(0)
			part.tag = "from storage hopper"
			return part

	def draw_local(self, surf, t):
		Hopper.draw_local(self, surf, t)
		self.draw_level_gauge(surf, t, len(self.contents), self.capacity)
