################################################################
#
#   Assembly Line - Machines page
#
################################################################

from pygame import Rect
from albow.resource import get_font
from albow.palette_view import PaletteView
from screen import ALScreen
from game import game
from format import format_dollars
from machine_type_view import MachineTypePaletteBase

palette_margin = 16

icon_size = (96, 48)
icon_margin = 8
icon_label_lines = 3
icon_label_font = get_font(10, "Vera.ttf")
icon_label_height = icon_label_lines * icon_label_font.get_linesize()

class MachinesPage(ALScreen):

	fg_color = (0, 0, 0)
	bg_color = (103, 177, 109)

	def __init__(self, shell):
		ALScreen.__init__(self, shell)
		pm = palette_margin
		r = Rect(pm, pm, self.width - 2 * pm, self.height - 2 * pm)
		self.machines_view = MachinesView(r, self.game)
		self.add(self.machines_view)


class MachinesView(MachineTypePaletteBase):

	fg_color = (0, 0, 0)
	sel_color = (0, 0, 255)
	highlight_style = 'frame'

	def __init__(self, rect, game):
		self.game = game
		iw, ih = icon_size
		cw = iw + 2 * icon_margin
		ch = ih + 3 * icon_margin + icon_label_height
		ncols = rect.width // cw
		nrows = rect.height // ch
		PaletteView.__init__(self, (cw, ch), nrows, ncols, scrolling = True)
		self.topleft = rect.topleft
	
	def factory(self):
		return self.game.factory()
	
	def draw_item(self, surf, n, rect):
		mtype = self.machine_type_no(n)
		icon = mtype.icon
		x, y = rect.midtop
		r = icon.get_rect()
		r.center = x, y + icon_margin + icon_size[1] // 2
		surf.blit(icon, r)
		x = rect.centerx
		y = rect.bottom - icon_margin - icon_label_height
		h = icon_label_font.get_linesize()
		def text_lines():
			stock = game.company.num_machines_in_storage(mtype)
			cost = format_dollars(mtype.cost)
			yield mtype.title
			yield cost
			if stock:
				yield "%s in storage" % stock
		for text in text_lines():
			buf = icon_label_font.render(text, True, self.fg_color)
			r = buf.get_rect()
			r.midtop = (x, y)
			surf.blit(buf, r)
			y += h
