################################################################
#
#   Assembly Line - Playing Screen
#
################################################################

from albow.tab_panel import TabPanel
from screen import ALScreen
from game import game
from company_page import CompanyPage
from products_page import ProductsPage
from factory_page import FactoryPage
from machines_page import MachinesPage
from inspection_page import InspectionPage
from stats_page import StatsPage

#factory_floor_color = (0, 135, 153)

class PlayScreen(ALScreen):

	def __init__(self, shell):
		ALScreen.__init__(self, shell)
		self.tabs = TabPanel(rect = self.rect)
		self.tabs.tab_fg_color = (0, 0, 0)
		#self.tabs.selected_tab_bg_color = FactoryPage.bg_color
		self.add(self.tabs)
		page_height = self.tabs.page_height()
		self.company_page = CompanyPage(shell, page_height)
		self.products_page = ProductsPage(shell)
		self.factory_page = FactoryPage(shell)
		self.machines_page = MachinesPage(shell)
		self.inspection_page = InspectionPage(shell)
		self.stats_page = StatsPage(shell, page_height)
		self.tabs.add_page("Company", self.company_page)
		self.tabs.add_page("Products", self.products_page)
		self.tabs.add_page("Factory", self.factory_page)
		self.tabs.add_page("Machines", self.machines_page)
		self.tabs.add_page("Inspection", self.inspection_page)
		self.tabs.add_page("Reports", self.stats_page)
	
	def show_company_page(self):
		self.tabs.show_page(self.company_page)

	def show_products_page(self):
		self.tabs.show_page(self.products_page)

	def show_factory_page(self):
		self.tabs.show_page(self.factory_page)

	def show_machines_page(self):
		self.tabs.show_page(self.machines_page)

	def show_inspection_page(self):
		self.tabs.show_page(self.inspection_page)

	def show_stats_page(self):
		self.tabs.show_page(self.stats_page)

	def begin_frame(self):
		game.begin_frame()
		if game.update_pending:
			game.update_pending = False
			self.invalidate()
		page = self.tabs.current_page
		if page:
			page.begin_frame()
