################################################################
#
#   Assembly Line - Reports
#
################################################################

from albow.controls import Column, ValueView
from albow.table_view import TableView, TableColumn as TC
from albow.resource import get_font
from decoration import Lineflow
from timing import period_start_date
from format import  format_month_and_year

heading_font = get_font(15, "VeraBd.ttf")
table_header_font = get_font(12, "VeraBd.ttf")
table_data_font = get_font(12, "Vera.ttf")

#-----------------------------------------------------------------------

def report_page(cls, selections = None):
	report_view = cls(selections)
	title_view = ReportTitleView(report_view)
	page = Lineflow(Column([title_view, report_view], align = 'l'))
	page.selections = selections
	return page

#-----------------------------------------------------------------------

class ReportTitleView(ValueView):

	font = heading_font
	
	def __init__(self, client, width = 500, **kwds):
		self.client = client
		ValueView.__init__(self, width = width, **kwds)
	
	def get_value(self):
		return self.client.title_text()
		
#-----------------------------------------------------------------------

class ReportView(object):

	title = "Untitled"
	selections = None

	def title_text(self):
		text = self.title
		sel = self.selections
		if sel:
			k = sel.kind
			if k == 'total':
				parms = "Total"
			else:
				p, n = sel.period_range()
				d = period_start_date(p)
				parms = format_month_and_year(period_start_date(p))
				if n > 1:
					end = format_month_and_year(period_start_date(p + n - 1))
					parms = "%s to %s" % (parms, end)
			text = "%s - %s" % (text, parms)
		return text

#-----------------------------------------------------------------------

class ReportTableView(ReportView, TableView):

	header_font = table_header_font
	font = table_data_font

	def __init__(self, selections, **kwds):
		self.selections = selections
		TableView.__init__(self, **kwds)
