################################################################
#
#   Assembly Line - Research subpage
#
################################################################

from __future__ import division
from albow.controls import Label, Row, Column, Grid, Frame, ValueView, Button, \
	IntEditor, IntField, BoolField, ValueView
from albow.dialogs import alert, Dialog
from albow.table_view import TableView, TableColumn as TC
from albow.resource import get_font
from decoration import Lineflow
from format import format_dollars, format_money, format_bool
from imath import iround
from game import game

#-----------------------------------------------------------------------

heading_font = get_font(15, "VeraBd.ttf")
subheading_font = get_font(12, "VeraBd.ttf")
table_header_font = get_font(12, "VeraBd.ttf")
table_data_font = get_font(12, "Vera.ttf")

#-----------------------------------------------------------------------

def ResearchSubpage():
	label = Label("Products Under Development", font = heading_font)
	table = ResearchTable()
	controls = Button("Settings...",
		enable = selected_product_is_under_development,
		action = edit_product_under_development)
	contents = Column([
		label,
		table,
		controls,
	], align = 'l', expand = 1)
	return Lineflow(contents)
		
#-----------------------------------------------------------------------

class ResearchTable(TableView):

	header_font = table_header_font
	font = table_data_font

	columns = [
		TC("Product",          150, 'l'),
		TC("Per Month",         70, 'r', format_dollars),
		TC("Est Remaining",    110, 'r', "%.1f months"),
		TC("Done",              50, 'r', "%.1f%%"),
		#TC("Est Devel Cost",  100, 'r', format_dollars),
		#TC("Spent",            60, 'r', format_dollars),
	]
	
	def num_rows(self):
		return game.company.num_products_under_development()

	def row_is_selected(self, n):
		p = game.company.product_under_development_no(n)
		return game.product_is_selected(p)
	
	def click_row(self, n, e):
		p = game.company.product_under_development_no(n)
		game.select_product(p)
	
	def row_data(self, n):
		company = game.company
		p = company.product_under_development_no(n)
		h = company.find_product_history(p)
		return (
			p.title,
			#p.development_cost,
			h.research_budget,
			#h.research_spending,
			p.estimated_development_time(h, h.research_budget),
			h.research_done * 100.0,
		)

#-----------------------------------------------------------------------

def selected_product_is_under_development():
	return game.company.product_is_under_development(game.selected_product)

def edit_product_under_development():
	product = game.selected_product
	history = game.company.find_product_history(product)
	dlog = ResearchDialog(product, history)
	if dlog.present() == "OK":
		history.research_budget = dlog.budget

#-----------------------------------------------------------------------

class ResearchDialog(Dialog):

	def __init__(self, product, history):
		self.product = product
		self.history = history
		name_field = Label(product.title)
		budget_field = IntEditor(min = 0, width = "999999",
			model = self, attribute = 'budget')
		budget_row = Row([
			Label("$"), budget_field, Label("per month on development")
		], spacing = 5)
		estimate_field = ValueView(get_value = self.est_time,
			width = 50, format = "%.1f", align = 'l')
		estimate_row = Row([estimate_field, Label("months development remaining")])
		grid = Grid([
			[Label("Product"), name_field],
			[Label("Spend"), budget_row],
			[Label("Estimate"), estimate_row],
		])
		budget = history.research_budget
		if not budget:
			budget = iround(product.development_cost / product.months_to_develop)
		self.budget = budget
		Dialog.__init__(self, grid, responses = ["OK", "Cancel"])

	def est_time(self):
		return self.product.estimated_development_time(self.history,
			self.budget)
