################################################################
#
#   Assembly Line - Screen
#
################################################################

import os, sys
from optparse import OptionParser
from pygame.locals import FULLSCREEN

screen_size = (800, 600)
fullscreen = False
flags = 0
frame_time = 50
game_minutes_per_second = 60
game_speeds = [0, 1, 5, 20] # indexed by speed
speed_names = ["Pause", "Slow", "Medium", "Fast"]
record_transactions = False

#app_version = (1, 0, 0)
app_magic = "ALin"

# Current save file info
save_file_version = 2         # Current save file version
save_app_version = (0, 5, 0)  # Earliest app version that can load it
save_file_magic = "SAVE"
save_file_suffix = ".alg"
save_file_default_name = "Assembly_Line_Game"

# Previous save file version info
save_min_version = 2          # Earliest version we can load
save_version_ranges = {       # App versions that can load
	1: [(0, 1, 0), (0, 4, 0)],  #   earlier save file formats
}

# The following paths are relative to the directory containing
# the Game directory or the .app bundle.
default_save_dir_name = "Saves"

usage = "%prog [options] [saved_game]"

options = None
macosx_bundle = False

option_defs = [
	("-f,--fullscreen", 'fullscreen',  "Run in full-screen mode"),
	("-w,--windowed",   'windowed',    "Run in windowed mode"),
	("-s,--size",       'size',        "Window size: <width>x<height>"),
	("-n,--newgame",    'new_game',    "Start new game"),
	("--cp", 'dbg_company_page',  "Start in company page"),
	("--pp", 'dbg_products_page', "Start in products page"),
	("--fp", 'dbg_factory_page',  "Start in factory page"),
	("--mp", 'dbg_machines_page', "Start in machines page"),
	("--ip", 'dbg_inspection_page', "Start in inspection page"),
	("--rp", 'dbg_stats_page',    "Start in reports page"),
	("--debug-retailer", 'dbg_retailer', "Debug retailer simulation"),
	("--debug-customer", 'dbg_customer', "Debug customer simulation"),
]

debug_options = [
	("--zc", 'dbg_no_costs',        "Don't charge for equipment"),
	("--ac", 'dbg_add_cash',        "Add some cash on loading game"),
	("--im", 'dbg_increase_market', "Add <n> customers on loading game", 'int'),
	("--am", 'dbg_add_machine',     "Add <machine> to those available", 'str'),
]

class DefaultingOptions(object):

	def __init__(self, d):
		self.__dict__.update(d)

	def __getattr__(self, name):
		return None

def extract_macosx_finder_launch_args():
	#  When launched from the Finder under MacOSX, we get called with
	#  a command line argument of the form -psn_N_NNNNN. We set a flag
	#  to remember this and delete the argument from argv.
	global macosx_bundle
	args = sys.argv
	if len(args) > 1 and args[1].startswith("-psn_"):
		macosx_bundle = True
		del args[1]

def get_command_line_options():
	global options
	extract_macosx_finder_launch_args()
	parser = OptionParser(usage = usage)
	def add_option(flags, dest, help, type = None):
		if type:
			action = 'store'
		else:
			action = 'store_true'
		if type == 'str':
			type = None
		parser.add_option(action = action, dest = dest, help = help,
			type = type, *flags.split(","))
	for desc in option_defs:
		add_option(*desc)
	if os.environ.get("AL_DEBUG"):
		for desc in debug_options:
			add_option(*desc)
	opts, args = parser.parse_args()
	if args:
		opts.filename = args[0]
	else:
		opts.filename = None
	override_default_settings(opts)
	options = DefaultingOptions(opts.__dict__)

def override_default_settings(options):
	global fullscreen, screen_size, frames_per_second
	if options.fullscreen:
		fullscreen = True
	if options.windowed:
		fullscreen = False
	if fullscreen:
		flags |= FULLSCREEN
	if options.size:
		try:
			screen_size = map(int, options.size.split("x"))
			if len(screen_size) <> 2:
				raise ValueError
		except ValueError:
			fatal("Invalid --size argument")
	#frames_per_second = secs_to_frames(1.0)
	frames_per_second = 1000 // frame_time

def fatal(mess):
	sys.stderr.write("%s: %s\n" % (sys.argv[0], mess))
	sys.exit(1)

def get_program_dir():
	#  Find the directory containing the program and the default
	#  Save and Mods directories. For the MacOSX bundle version, this is
	#  the directory containing the .app bundle. For other versions,
	#  this is the directory containing the Game directory.
	d = os.path.dirname
	path = d(d(sys.path[0]))
	if macosx_bundle:
		path = d(path)
	return path

def get_default_save_dir():
	parent = get_program_dir()
	return os.path.join(parent, default_save_dir_name)

def game_minutes_to_frames(t):
	return t * frames_per_second // game_minutes_per_second

def secs_to_frames(t):
	return int(round(1000.0 * t / frame_time))
