################################################################
#
#   Assembly Line - Shell
#
################################################################

import os, sys
from pygame.locals import *
from albow import Cancel
from albow.shell import Shell
from albow.dialogs import alert, ask
from albow.file_dialogs import request_old_filename, request_new_filename
from game import game
from menu_screen import MenuScreen
from play_screen import PlayScreen
import settings
import company
import machines

class ALShell(Shell):

	bg_color = (224, 224, 224)

	def __init__(self, display):
		Shell.__init__(self, display)
		self.redraw_every_frame = False
		self.set_timer(settings.frame_time)
		self.game = game
		self.menu_screen = MenuScreen(self)
		self.play_screen = PlayScreen(self)
		options = settings.options
		self.show_menu()
		#game.new_game()
		company.debug_retailer = options.dbg_retailer
		company.debug_customer = options.dbg_customer
		if options.filename:
			self.load_game_file(options.filename)
		elif options.new_game:
			self.new_game()
		if game.game_in_progress():
			name = options.dbg_add_machine
			if name:
				mtype = machines.find_machine_type(name)
				if mtype:
					game.company.add_available_machine(mtype)
			if options.dbg_company_page:
				self.show_company_page()
			if options.dbg_products_page:
				self.show_products_page()
			if options.dbg_factory_page:
				self.show_factory_page()
			if options.dbg_machines_page:
				self.show_machines_page()
			if options.dbg_inspection_page:
				self.show_inspection_page()
			if options.dbg_stats_page:
				self.show_stats_page()
	
	def show_menu(self):
		self.show_screen(self.menu_screen)

	def show_play_screen(self):
		self.show_screen(self.play_screen)
	
	def show_company_page(self):
		self.show_play_screen()
		self.play_screen.show_company_page()

	def show_products_page(self):
		self.show_play_screen()
		self.play_screen.show_products_page()

	def show_factory_page(self):
		self.show_play_screen()
		self.play_screen.show_factory_page()
	
	def show_machines_page(self):
		self.show_play_screen()
		self.play_screen.show_machines_page()
	
	def show_inspection_page(self):
		self.show_play_screen()
		self.play_screen.show_inspection_page()
	
	def show_stats_page(self):
		self.show_play_screen()
		self.play_screen.show_stats_page()
	
	def new_game(self):
		if game.game_in_progress():
			ans = ask("Abort current game and start a new one?", ["OK", "Cancel"])
			if ans <> "OK":
				return
		self.game.new_game()
		self.show_company_page()
	
	def load_game(self):
		dir = self.game.get_save_dir()
		path = request_old_filename(suffixes = [settings.save_file_suffix],
			directory = dir)
		if path:
			self.load_game_file(path)
	
	def load_game_file(self, path):
		try:
			self.game.load_game(path)
			self.show_company_page()
			if settings.options.dbg_add_cash:
				self.game.company.cash += 20000
		except EnvironmentError, e:
			alert("Unable to load '%s': %s" % (
				os.path.basename(path), e))
	
	def save_game(self):
		game = self.game
		old_path = game.get_save_path()
		new_path = request_new_filename(prompt = "Save game as:",
			suffix = settings.save_file_suffix, pathname = old_path)
		if new_path:
			try:
				game.save_game(new_path)
			except EnvironmentError, e:
				alert("Unable to save '%s': %s" % (
					os.path.basename(new_path), mess))
	
	def resume_game(self):
		self.show_play_screen()

	def confirm_quit(self):
		return ask("Quit the game?") == "OK"

	def begin_frame(self):
		screen = self.current_screen
		if screen:
			screen.begin_frame()
		game.flush_sound_queue()

	def key_down(self, e):
		if e.cmd:
			self.cmd_key(e)
		elif e.alt:
			self.alt_key(e)
		else:
			Shell.key_down(self, e)
	
	def cmd_key(self, e):
		k = e.key
		if k == K_RIGHT:
			game.change_speed(1)
		elif k == K_LEFT:
			game.change_speed(-1)
		elif k == K_n:
			self.new_game()
		elif k == K_o:
			self.load_game()
		elif k == K_s:
			self.save_game()
		elif k == K_r:
			self.resume_game()
		elif k == K_q:
			self.quit()
		else:
			Shell.key_down(self, e)

	def alt_key(self, e):
		k = e.key
		if k == K_c:
			self.show_company_page()
		elif k == K_p:
			self.show_products_page()
		elif k == K_f:
			self.show_factory_page()
		elif k == K_m:
			self.show_machines_page()
		elif k == K_i:
			self.show_inspection_page()
		elif k == K_r:
			self.show_stats_page()
		else:
			Shell.key_down(self, e)
