################################################################
#
#   Assembly Line - Statistics Page
#
################################################################

from albow.controls import Label, Row, Column, Grid, Frame, ValueView, \
	RadioButton
#from albow.palette_view import PaletteView
from albow.table_view import TableView, TableColumn as TC
from albow.resource import get_font
from screen import ALScreen
from decoration import Lineflow
from controls import MonthField, YearField
from format import format_dollars, format_month_and_year
from timing import period_start_date
from game import game
from report import report_page
from reports.sales_report import SalesReport
from reports.marketing_report import MarketingReport
from reports.factory_report import FactoryReport
from reports.financial_report import FinancialReport
from decoration import PostitTabPanel

#-----------------------------------------------------------------------

heading_font = get_font(15, "VeraBd.ttf")
table_header_font = get_font(12, "VeraBd.ttf")
table_data_font = get_font(12, "Vera.ttf")

#-----------------------------------------------------------------------

class StatsPage(ALScreen):
	
	#bg_color = (119, 15, 5) # burgundy
	#bg_color = (157, 0, 0)
	#bg_color = (155, 154, 15)
	#bg_color = (74, 155, 15)
	#bg_color = (138, 51, 36) # burned umber
	#bg_color = (166, 125, 61) # bronzeii
	#bg_color = (210, 180, 140) # tan
	#bg_color = (205, 170, 125) # burlywood3
	#bg_color = (139, 115, 85) # burlywood4
	#bg_color = (142, 107, 35) # sienna
	#bg_color = (205, 173, 0) # gold3
	#bg_color = (207, 181, 59) # oldgold
	#bg_color = (255, 215, 0) # gold
	bg_color = (163, 118, 17) # darkened packer gold
	margin = 16

	def __init__(self, shell, height):
		ALScreen.__init__(self, shell)
		m = self.margin
		h = height - 2 * m
		rs = ReportSelectionProxy()
		params = ParamsView(rs, get_visible = self.report_has_selections)
		sales_report = report_page(SalesReport, rs)
		marketing_report = report_page(MarketingReport)
		factory_report = report_page(FactoryReport)
		financial_report = report_page(FinancialReport)
		pages = PostitTabPanel([
			("Sales", sales_report),
			("Marketing", marketing_report),
			("Factory", factory_report),
			("Financial", financial_report),
		], anchor = 'ltrb')
		self.pages = pages
		contents = Column([
			params,
			pages,
		], align = 'l', expand = 1, anchor = 'ltrb')
		contents.rect = self.get_margin_rect()
		self.add(contents)
	
	def report_has_selections(self):
		return self.pages.current_page.selections is not None
	
#-----------------------------------------------------------------------

class ReportSelectionProxy(object):

	def __getattr__(self, name):
		return getattr(game.company.report_selection, name)
	
	def __setattr__(self, name, x):
		setattr(game.company.report_selection, name, x)

#-----------------------------------------------------------------------

def ParamsView(model, **kwds):

	def ParamOption(value):
		return RadioButton(model = model, attribute = 'kind',
			value = value)
	
	def LabelledOption(value, text):
		return Row([ParamOption(value), Label(text)], spacing = 5)
	
	opt_total = LabelledOption('total', "Total")
	opt_last3 = LabelledOption('last3', "Last 3 Months")
	opt_current = LabelledOption('current', "This Month")
	opt_specified = LabelledOption('month', "Month:")
	month_field = MonthField(model = model, attribute = 'month')
	year_field = YearField(model = model, attribute = 'year')
	date_row = Row([opt_specified, month_field, year_field], spacing = 5)
	return Row([
		opt_total,
		opt_last3,
		opt_current,
		date_row,
	], spacing = 20,
		bg_color = (224, 224, 224),
		margin = 5,
		border_width = 1,
		**kwds)
